@@ -2,7 +2,7 @@ package RedisDB::Parser::PP;
 
 use strict;
 use warnings;
-our $VERSION = "2.21";
+our $VERSION = "2.22";
 $VERSION = eval $VERSION;
 
 =head1 NAME
@@ -78,7 +78,9 @@ sub propagate_reply {
 sub parse {
     my ( $self, $data ) = @_;
     $self->{_buffer} .= $data;
-    1 while length $self->{_buffer} and $self->_parse_reply;
+    my $cnt = 0;
+    $cnt++ while length $self->{_buffer} and $self->_parse_reply;
+    return $cnt;
 }
 
 # $self->_parse_reply
